@@ -432,3 +432,16 @@
   )
 }
 
+# Sometimes .fromJSON doesn't work, but jsonlite::fromJSON will. See https://github.com/JaseZiv/worldfootballR/issues/201
+#' @importFrom purrr safely
+#' @importFrom jsonlite fromJSON
+#'
+#' @noRd
+safely_from_json <- function(...) {
+  f <- purrr::safely(.fromJSON, otherwise = NULL, quiet = TRUE)
+  resp <- f(...)
+  if (!is.null(resp)) {
+    return(resp)
+  }
+  jsonlite::fromJSON(...)
+}
