@@ -30,7 +30,8 @@
 #' }
 
 load_match_results <- function(country, gender, season_end_year, tier) {
-  dat_urls <- paste0("https://github.com/JaseZiv/worldfootballR_data/blob/master/data/match_results/", country, "_match_results.rds?raw=true")
+  
+  dat_urls <- paste0("https://github.com/JaseZiv/worldfootballR_data/releases/download/match_results/", country, "_match_results.rds")
 
   # collect_date <- .file_reader("https://github.com/JaseZiv/worldfootballR_data/blob/master/data/match_results/scrape_time_match_results.rds?raw=true")
   dat_df <- dat_urls %>% purrr::map_df(.file_reader)
@@ -86,7 +87,7 @@ load_match_comp_results <- function(comp_name) {
 
   f_name <- janitor::make_clean_names(comp_name)
 
-  dat_urls <- paste0("https://github.com/JaseZiv/worldfootballR_data/blob/master/data/match_results_cups/", f_name, "_match_results.rds?raw=true")
+  dat_urls <- paste0("https://github.com/JaseZiv/worldfootballR_data/releases/download/match_results_cups/", f_name, "_match_results.rds")
 
   dat_df <- dat_urls %>% purrr::map_df(.file_reader)
 
@@ -147,7 +148,7 @@ load_match_comp_results <- function(comp_name) {
 
 load_fb_big5_advanced_season_stats <- function(season_end_year = NA, stat_type, team_or_player) {
 
-  dat_url <- paste0("https://github.com/JaseZiv/worldfootballR_data/blob/master/data/fb_big5_advanced_season_stats/big5_", team_or_player, "_", stat_type, ".rds?raw=true")
+  dat_url <- paste0("https://github.com/JaseZiv/worldfootballR_data/releases/download/fb_big5_advanced_season_stats/big5_", team_or_player, "_", stat_type, ".rds")
   # collect_date <- .file_reader("https://github.com/JaseZiv/worldfootballR_data/blob/master/data/fb_big5_advanced_season_stats/scrape_time_big5_advanced_season_stats.rds?raw=true")
 
   dat_df <- tryCatch(.file_reader(dat_url), error = function(e) data.frame())
